Skip to contents

Adds a stamp reaction to a post using the AddStampToPost RPC.

Usage

add_stamp_to_post(client, post_id, stamp_id)

Arguments

client

A mixi2_client object created by mixi2_client().

post_id

ID of the post to stamp. Must be a post that mentions the application.

stamp_id

ID of the stamp to add. Must be an official stamp ID (see get_stamps()).

Value

A list representing the updated post object.

Details

The target post must be one that mentions the application. Only official stamps can be used. Each post can only receive one stamp from the application.

Examples

if (FALSE) { # \dontrun{
client  <- mixi2_client()
stamps  <- get_stamps(client)
stamp_id <- stamps[[1]]$stamps[[1]]$stampId
add_stamp_to_post(client, post_id = "target_post_id", stamp_id = stamp_id)
} # }