Skip to contents

Retrieves the list of official stamps available for the specified language using the GetStamps RPC.

Usage

get_stamps(client, language = "LANGUAGE_CODE_JP")

Arguments

client

A mixi2_client object created by mixi2_client().

language

Language code for official stamps. One of "LANGUAGE_CODE_JP" (Japanese, default) or "LANGUAGE_CODE_EN" (English). Pass NULL to return no official stamps.

Value

A list of official stamp sets. Each set contains a stamps element with individual stamp entries (including stamp_id and image URLs).

Examples

if (FALSE) { # \dontrun{
client <- mixi2_client()
stamps <- get_stamps(client)
first_stamp_id <- stamps[[1]]$stamps[[1]]$stampId
} # }