Skip to contents
mixi2r
0.0.0.9000
Reference
Changelog
Parse a public key from raw bytes or Base64 string
parse_public_key.Rd
Parse a public key from raw bytes or Base64 string
Usage
parse_public_key
(
public_key
)